#[non_exhaustive]pub enum UnsupportedReason {
Param {
name: String,
},
Field {
field: String,
only_supported_by: String,
},
UriType {
ty: String,
},
TransportLayer {
ty: String,
},
MissingParameter {
ty: String,
parameter: String,
},
Authority {
scheme: &'static str,
},
}Expand description
Categorised reason an Unsupported URI was rejected.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Param
A query parameter is not supported by the flakeref type.
Field
A field is recognised but only valid on a different set of types.
UriType
The URI scheme/type identifier is not known.
TransportLayer
The transport layer (the part after +) is not known.
MissingParameter
A required parameter for the type is missing.
Authority
The scheme does not accept a URL authority (//host). Nix rejects
the same shape; path://host/... is malformed even though it
superficially looks like a URL.