#[non_exhaustive]pub struct ForgeIdentity {
pub platform: GitForgePlatform,
pub owner: String,
pub repo: String,
pub domain: String,
}Expand description
Identity of a git-forge flake ref: (platform, owner, repo, domain).
Returned by FlakeRef::forge_identity for kinds that resolve to a
git forge (GitForge always; Resource(Git) does not; its
owner/repo/domain are extracted ad-hoc from a URL string and not
guaranteed to be present, so it returns None for forge_identity).
#[non_exhaustive] reserves room for future fields without breaking
downstream match arms.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.platform: GitForgePlatformowner: Stringrepo: Stringdomain: StringTrait Implementations
Sourceimpl Clone for ForgeIdentity
impl Clone for ForgeIdentity
Sourcefn clone(&self) -> ForgeIdentity
fn clone(&self) -> ForgeIdentity
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ForgeIdentity
impl Debug for ForgeIdentity
Sourceimpl PartialEq for ForgeIdentity
impl PartialEq for ForgeIdentity
Sourcefn eq(&self, other: &ForgeIdentity) -> bool
fn eq(&self, other: &ForgeIdentity) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ForgeIdentity
impl StructuralPartialEq for ForgeIdentity